@@ -2,14 +2,15 @@
 PyDetex
 https://github.com/ppizarror/PyDetex
 
-A python application that removes LaTeX code and transforms it to plain text for grammar checking or other things...
+PYDETEX
+An application that transforms LaTeX code to plain text.
 """
 
 import pydetex.version
 
 __author__ = 'Pablo Pizarro R.'
 __copyright__ = 'Copyright 2021 Pablo Pizarro R. @ppizarror'
-__description__ = 'A python application that removes LaTeX code and transforms it to plain text for grammar checking or other things...'
+__description__ = 'An application that transforms LaTeX code to plain text'
 __email__ = 'pablo@ppizarror.com'
 __keywords__ = 'latex detex parser gui'
 __license__ = 'MIT'
