@@ -110,7 +110,7 @@ class _LangManager(object):
                 'pipeline_simple_description': 'Removes common Tex commands, replaces cites and references',
                 'pipeline_strict': 'Strict',
                 'pipeline_strict_description': 'An extension of the Simple pipeline which removes all Tex commands and environments',
-                'placeholder': 'Write or paste here your \\texttt{LaTeX} code. It simply removes all tex-things and returns a friendly plain text!',
+                'placeholder': ut.open_file(ut.RESOURCES_PATH + 'placeholder_en.tex'),
                 'process': 'Process',
                 'process_clip': 'Process from clipboard',
                 'process_copy': 'Copy to clipboard',
@@ -202,7 +202,7 @@ class _LangManager(object):
                 'pipeline_simple_description': 'Elimina comandos Tex comunes, remplaza citas y referencias',
                 'pipeline_strict': 'Estricto',
                 'pipeline_strict_description': 'Una extensión del pipeline simple que elimina todos los entornos y comandos',
-                'placeholder': 'Escribe o pega aquí tu código \\texttt{LaTeX}. El programa simplemente eliminará todo lo relacionado a tex y retornará un lindo texto plano!',
+                'placeholder': ut.open_file(ut.RESOURCES_PATH + 'placeholder_es.tex'),
                 'process': 'Procesar',
                 'process_clip': 'Procesar desde portapapeles',
                 'process_copy': 'Copiar al portapapeles',
@@ -332,7 +332,7 @@ class Settings(object):
 
         self._default_settings = {
             self.CFG_CHECK_REPETITION: (False, bool, [True, False]),
-            self.CFG_FONT_SIZE: (11, int, self._valid_font_sizes),
+            self.CFG_FONT_SIZE: (12 if ut.IS_OSX else 11, int, self._valid_font_sizes),
             self.CFG_LANG: ('en', str, self._lang.get_available()),
             self.CFG_LAST_OPENED_DAY: (ut.get_number_of_day(), int, lambda x: x >= 0),
             self.CFG_LAST_OPENED_FOLDER: ('/', str, lambda x: os.path.isdir(x)),
