@@ -618,12 +618,15 @@ class DictionaryGUI(object):
 
         :param word: Word
         """
-        self._text_out.clear()
-        self._word.delete(0, tk.END)
-        stemmer = ut.make_stemmer(self._lang)
-        if stemmer is not None and self._stemmer:
-            word = stemmer.stem(word)
-        self.root.after(50, lambda: self._word.insert(0, word))
+        try:
+            self._text_out.clear()
+            self._word.delete(0, tk.END)
+            stemmer = ut.make_stemmer(self._lang)
+            if stemmer is not None and self._stemmer:
+                word = stemmer.stem(word)
+            self.root.after(50, lambda: self._word.insert(0, word))
+        except tk.TclError:
+            pass
 
     def close(self) -> None:
         """
@@ -720,7 +723,11 @@ class RichText(tk.Text):
             self.clear()
         for t in ut.split_tags(s, list(fonts.FONT_TAGS.values())):
             tag, text = t
-            self.insert('end', text, fonts.TAGS_FONT[tag] if font_format else 'normal')
+            try:
+                self.insert('end', text, fonts.TAGS_FONT[tag] if font_format else 'normal')
+            except tk.TclError:
+                chars = [text[j] for j in range(len(text)) if ord(text[j]) in range(65536)]
+                self.insert('end', ''.join(chars), fonts.TAGS_FONT[tag] if font_format else 'normal')
 
     def clear(self) -> None:
         """
