@@ -236,9 +236,7 @@ class PyDetexGUI(object):
         filename_dir = os.path.dirname(filename)
         self._cfg.set(self._cfg.CFG_LAST_OPENED_FOLDER, filename_dir)
         try:
-            f = open(filename, 'r')
-            text = ''.join(f.readlines())
-            f.close()
+            text = ut.open_file(filename)
             self._clear()
             self._insert_in(text)
             self._cfg.save()
@@ -287,9 +285,7 @@ class PyDetexGUI(object):
             self._root.after_cancel(self._detect_language_event_id)
 
         if event.char in string.printable and event.char != '':
-            self._status(self._cfg.lang('status_writing'), True)
-        else:
-            self._status_clear()
+            self._status(self._cfg.lang('status_writing'), True, 1000)
         self._detect_language_event_id = self._root.after(100, self._detect_language)
         self._process_cursor_in(event)
         return event
@@ -620,7 +616,7 @@ class PyDetexGUI(object):
         self._dictionary_window.on_destroy = self._close_dictionary
         try:
             self._dictionary_window.root.update()
-        except AttributeError:
+        except (AttributeError, tk.TclError):
             pass
 
     def _close_dictionary(self) -> None:
