@@ -3,11 +3,12 @@ PyDetex
 https://github.com/ppizarror/PyDetex
 
 UTILS
-Several text utils.
+Module that contain all util methods and classes used in parsers and pipelines,
+from tex, language, and low-level.
 """
 
 __all__ = [
-    'apply_tag_between_inside',
+    'apply_tag_between_inside_char_command',
     'apply_tag_tex_commands',
     'apply_tag_tex_commands_no_argv',
     'Button',
@@ -17,6 +18,7 @@ __all__ = [
     'find_tex_command_char',
     'find_tex_commands',
     'find_tex_commands_noargv',
+    'find_tex_environments',
     'format_number_d',
     'get_diff_startend_word',
     'get_language_name',
@@ -26,11 +28,14 @@ __all__ = [
     'IS_OSX',
     'LangTexTextTags',
     'make_stemmer',
+    'open_file',
     'RESOURCES_PATH',
     'split_tags',
     'syntax_highlight',
+    'TEX_COMMAND_CHARS',
+    'TEX_EQUATION_CHARS',
+    'tex_to_unicode',
     'tokenize',
-    'VALID_TEX_COMMAND_CHARS',
     'validate_float',
     'validate_int'
 ]
@@ -158,19 +163,18 @@ def syntax_highlight(s: str) -> str:
     """
     Syntax highlighter.
 
-    :param s: Latex code
+    :param s: Latex string code
     :return: Code with format
     """
     # Add initial normal
     s = _FONT_TAGS['normal'] + s
 
     # Format equations
-    s = apply_tag_between_inside(
+    s = apply_tag_between_inside_char_command(
         s=s,
-        symbols_char=('$', '$'),
+        symbols_char=TEX_EQUATION_CHARS,
         tags=(_FONT_TAGS['equation_char'], _FONT_TAGS['equation_inside'],
-              _FONT_TAGS['equation_char'], _FONT_TAGS['normal']),
-        ignore_escape=True
+              _FONT_TAGS['equation_char'], _FONT_TAGS['normal'])
     )
 
     # Format commands with {arguments}
@@ -212,3 +216,16 @@ def get_number_of_day() -> int:
     :return: Day number
     """
     return datetime.datetime.now().timetuple().tm_yday
+
+
+def open_file(f: str) -> str:
+    """
+    Open file and return its string.
+
+    :param f: Filename
+    :return: File content
+    """
+    o = open(f, 'r', encoding='utf-8')
+    text = ''.join(o.readlines())
+    o.close()
+    return text
